@@ -60,7 +60,7 @@ mod private {
     //! Sealing the HostFunctionKind because it shouldn't be implemented
     //! by any type outside.
     //! See:
-    //! https://rust-lang.github.io/api-guidelines/future-proofing.html#c-sealed
+    //! <https://rust-lang.github.io/api-guidelines/future-proofing.html#c-sealed>
     pub trait HostFunctionKindSealed {}
     impl HostFunctionKindSealed for super::WithEnv {}
     impl HostFunctionKindSealed for super::WithoutEnv {}
@@ -156,20 +156,6 @@ impl Function {
         Self(function_impl::Function::new_with_env(store, env, ty, func))
     }
 
-    #[deprecated(
-        since = "3.0.0",
-        note = "new_native() has been renamed to new_typed()."
-    )]
-    /// Creates a new host `Function` from a native function.
-    pub fn new_native<F, Args, Rets>(store: &mut impl AsStoreMut, func: F) -> Self
-    where
-        F: HostFunction<(), Args, Rets, WithoutEnv> + 'static + Send + Sync,
-        Args: WasmTypeList,
-        Rets: WasmTypeList,
-    {
-        Self::new_typed(store, func)
-    }
-
     /// Creates a new host `Function` from a native function.
     pub fn new_typed<F, Args, Rets>(store: &mut impl AsStoreMut, func: F) -> Self
     where
@@ -180,24 +166,6 @@ impl Function {
         Self(function_impl::Function::new_typed(store, func))
     }
 
-    #[deprecated(
-        since = "3.0.0",
-        note = "new_native_with_env() has been renamed to new_typed_with_env()."
-    )]
-    /// Creates a new host `Function` with an environment from a native function.
-    pub fn new_native_with_env<T: Send + 'static, F, Args, Rets>(
-        store: &mut impl AsStoreMut,
-        env: &FunctionEnv<T>,
-        func: F,
-    ) -> Self
-    where
-        F: HostFunction<T, Args, Rets, WithEnv> + 'static + Send + Sync,
-        Args: WasmTypeList,
-        Rets: WasmTypeList,
-    {
-        Self::new_typed_with_env(store, env, func)
-    }
-
     /// Creates a new host `Function` with an environment from a typed function.
     ///
     /// The function signature is automatically retrieved using the
@@ -352,20 +320,6 @@ impl Function {
         Self(function_impl::Function::from_vm_funcref(store, funcref))
     }
 
-    /// Transform this WebAssembly function into a native function.
-    /// See [`TypedFunction`] to learn more.
-    #[deprecated(since = "3.0.0", note = "native() has been renamed to typed().")]
-    pub fn native<Args, Rets>(
-        &self,
-        store: &impl AsStoreRef,
-    ) -> Result<TypedFunction<Args, Rets>, RuntimeError>
-    where
-        Args: WasmTypeList,
-        Rets: WasmTypeList,
-    {
-        self.typed(store)
-    }
-
     /// Transform this WebAssembly function into a typed function.
     /// See [`TypedFunction`] to learn more.
     ///
