@@ -32,8 +32,6 @@ pub(crate) mod instance;
 mod js_handle;
 pub(crate) mod mem_access;
 pub(crate) mod module;
-#[cfg(feature = "wasm-types-polyfill")]
-mod module_info_polyfill;
 pub(crate) mod store;
 pub(crate) mod trap;
 pub(crate) mod typed_function;
