@@ -35,15 +35,15 @@ impl Drop for RemoveTestsOnDrop {
 
 fn make_package() {
     let wasmer_root_dir = find_wasmer_base_dir();
-    let _ = std::fs::create_dir_all(&format!("{wasmer_root_dir}/package/lib"));
-    let _ = std::fs::create_dir_all(&format!("{wasmer_root_dir}/package/include"));
+    let _ = std::fs::create_dir_all(format!("{wasmer_root_dir}/package/lib"));
+    let _ = std::fs::create_dir_all(format!("{wasmer_root_dir}/package/include"));
     let _ = std::fs::copy(
-        &format!("{wasmer_root_dir}/lib/c-api/tests/wasm.h"),
-        &format!("{wasmer_root_dir}/package/include/wasm.h"),
+        format!("{wasmer_root_dir}/lib/c-api/tests/wasm.h"),
+        format!("{wasmer_root_dir}/package/include/wasm.h"),
     );
     let _ = std::fs::copy(
-        &format!("{wasmer_root_dir}/lib/c-api/tests/wasmer.h"),
-        &format!("{wasmer_root_dir}/package/include/wasmer.h"),
+        format!("{wasmer_root_dir}/lib/c-api/tests/wasmer.h"),
+        format!("{wasmer_root_dir}/package/include/wasmer.h"),
     );
     #[cfg(target_os = "windows")]
     let _ = std::fs::copy(
@@ -57,13 +57,13 @@ fn make_package() {
     );
     #[cfg(not(target_os = "windows"))]
     let _ = std::fs::copy(
-        &format!("{wasmer_root_dir}/target/release/libwasmer.so"),
-        &format!("{wasmer_root_dir}/package/lib"),
+        format!("{wasmer_root_dir}/target/release/libwasmer.so"),
+        format!("{wasmer_root_dir}/package/lib"),
     );
     #[cfg(not(target_os = "windows"))]
     let _ = std::fs::copy(
-        &format!("{wasmer_root_dir}/target/release/libwasmer.lib"),
-        &format!("{wasmer_root_dir}/package/lib"),
+        format!("{wasmer_root_dir}/target/release/libwasmer.lib"),
+        format!("{wasmer_root_dir}/package/lib"),
     );
     println!("copying done (make package)");
 }
@@ -93,7 +93,7 @@ impl Config {
                 // run make build-capi
                 let mut cmd = std::process::Command::new("make");
                 cmd.arg("build-capi");
-                cmd.current_dir(wasmer_base_dir.clone());
+                cmd.current_dir(&wasmer_base_dir);
                 let result = cmd.output();
                 println!("make build-capi: {result:#?}");
 
@@ -101,7 +101,7 @@ impl Config {
                 // run make package
                 let mut cmd = std::process::Command::new("make");
                 cmd.arg("package-capi");
-                cmd.current_dir(wasmer_base_dir.clone());
+                cmd.current_dir(&wasmer_base_dir);
                 let result = cmd.output();
                 make_package();
                 println!("make package: {result:#?}");
@@ -260,7 +260,7 @@ fn test_run() {
             vcvars.arg("/C");
             vcvars.arg(&path);
             vcvars.arg("x64");
-            vcvars.current_dir(&vcvars_bat_path_parent);
+            vcvars.current_dir(vcvars_bat_path_parent);
 
             // compile
             let output = vcvars
@@ -285,8 +285,8 @@ fn test_run() {
             }
             // execute
             let mut command = std::process::Command::new(&exe_outpath);
-            command.env("PATH", newpath.clone());
-            command.current_dir(exe_dir.clone());
+            command.env("PATH", &newpath);
+            command.current_dir(&exe_dir);
             println!("executing {test}: {command:?}");
             println!("setting current dir = {exe_dir}");
             let output = command
@@ -359,8 +359,8 @@ fn test_run() {
 
             // execute
             let mut command = std::process::Command::new(&format!("{manifest_dir}/../{test}"));
-            command.env("LD_PRELOAD", libwasmer_so_path.clone());
-            command.current_dir(exe_dir.clone());
+            command.env("LD_PRELOAD", &libwasmer_so_path);
+            command.current_dir(&exe_dir);
             println!("execute: {command:#?}");
             let output = command
                 .output()
@@ -448,7 +448,7 @@ fn fixup_symlinks_inner(include_paths: &[String], log: &mut String) -> Result<()
     log.push_str(&format!("fixup symlinks: {include_paths:#?}"));
     let regex = regex::Regex::new(INCLUDE_REGEX).unwrap();
     for path in include_paths.iter() {
-        let file = match std::fs::read_to_string(&path) {
+        let file = match std::fs::read_to_string(path) {
             Ok(o) => o,
             _ => continue,
         };
@@ -456,9 +456,9 @@ fn fixup_symlinks_inner(include_paths: &[String], log: &mut String) -> Result<()
         log.push_str(&format!("first 3 lines of {path:?}: {:#?}\n", lines_3));
 
         let parent = std::path::Path::new(&path).parent().unwrap();
-        if let Ok(symlink) = std::fs::read_to_string(parent.clone().join(&file)) {
+        if let Ok(symlink) = std::fs::read_to_string(parent.join(&file)) {
             log.push_str(&format!("symlinking {path:?}\n"));
-            std::fs::write(&path, symlink)?;
+            std::fs::write(path, symlink)?;
         }
 
         // follow #include directives and recurse
@@ -469,9 +469,9 @@ fn fixup_symlinks_inner(include_paths: &[String], log: &mut String) -> Result<()
         log.push_str(&format!("regex captures: ({path:?}): {:#?}\n", filepaths));
         let joined_filepaths = filepaths
             .iter()
-            .filter_map(|s| {
-                let path = parent.clone().join(s);
-                Some(format!("{}", path.display()))
+            .map(|s| {
+                let path = parent.join(s);
+                format!("{}", path.display())
             })
             .collect::<Vec<_>>();
         fixup_symlinks_inner(&joined_filepaths, log)?;
