@@ -45,9 +45,9 @@ pub struct CmdAppDeploy {
     #[clap(long)]
     pub publish_package: bool,
 
-    /// The path to the app.yaml file.
+    /// The path to the directory containing the `app.yaml` file.
     #[clap(long)]
-    pub path: Option<PathBuf>,
+    pub dir: Option<PathBuf>,
 
     /// Do not wait for the app to become reachable.
     #[clap(long)]
@@ -76,7 +76,7 @@ pub struct CmdAppDeploy {
     /// If specified via this flag, the app_name will be overridden. Otherwise, the `app.yaml` is
     /// inspected and, if there is no `name` field in the spec file, if running interactive the
     /// user will be prompted to insert an app name, otherwise the deployment will fail.
-    #[clap(long)]
+    #[clap(long, name = "name")]
     pub app_name: Option<String>,
 
     /// Whether or not to automatically bump the package version if publishing.
@@ -89,6 +89,31 @@ pub struct CmdAppDeploy {
     /// operation.
     #[clap(long)]
     pub quiet: bool,
+
+    // - App creation -
+    /// A reference to the template to use when creating an app to deploy.
+    ///
+    /// It can be either an URL to a github repository - like
+    /// `https://github.com/wasmer-examples/php-wasmer-starter` -  or the name of a template that
+    /// will be searched for in the selected registry, like `astro-starter`.
+    #[clap(
+        long,
+        conflicts_with = "package",
+        conflicts_with = "use_local_manifest"
+    )]
+    pub template: Option<String>,
+
+    /// Name of the package to use when creating an app to deploy.
+    #[clap(
+        long,
+        conflicts_with = "template",
+        conflicts_with = "use_local_manifest"
+    )]
+    pub package: Option<String>,
+
+    /// Whether or not to search (and use) a local manifest when creating an app to deploy.
+    #[clap(long, conflicts_with = "template", conflicts_with = "package")]
+    pub use_local_manifest: bool,
 }
 
 impl CmdAppDeploy {
@@ -119,10 +144,7 @@ impl CmdAppDeploy {
                 false => PublishWait::Container,
             },
             timeout: humantime::Duration::from_str("2m").unwrap(),
-            package_namespace: match manifest.package {
-                Some(_) => None,
-                None => Some(owner),
-            },
+            package_namespace: Some(owner),
             non_interactive: self.non_interactive,
             bump: self.bump,
             api: self.api.clone(),
@@ -172,22 +194,23 @@ impl CmdAppDeploy {
         eprintln!("It seems you are trying to create a new app!");
 
         let create_cmd = CmdAppCreate {
-            template: None,
+            quiet: self.quiet,
             deploy_app: false,
             no_validate: false,
             non_interactive: false,
             offline: false,
-            owner: None,
-            app_name: None,
+            owner: self.owner.clone(),
+            app_name: self.app_name.clone(),
             no_wait: self.no_wait,
             api: self.api.clone(),
             env: self.env.clone(),
             fmt: ItemFormatOpts {
                 format: self.fmt.format,
             },
-            package: None,
-            app_dir_path: None,
-            use_local_manifest: false,
+            package: self.package.clone(),
+            template: self.template.clone(),
+            app_dir_path: self.dir.clone(),
+            use_local_manifest: self.use_local_manifest,
             new_package_name: None,
         };
 
@@ -203,7 +226,7 @@ impl AsyncCliCommand for CmdAppDeploy {
         let client =
             login_user(&self.api, &self.env, !self.non_interactive, "deploy an app").await?;
 
-        let base_dir_path = self.path.clone().unwrap_or(std::env::current_dir()?);
+        let base_dir_path = self.dir.clone().unwrap_or(std::env::current_dir()?);
         let (app_config_path, base_dir_path) = {
             if base_dir_path.is_file() {
                 (
@@ -219,16 +242,13 @@ impl AsyncCliCommand for CmdAppDeploy {
             }
         };
 
-        if !app_config_path.is_file() {
-            if !self.non_interactive {
-                // Create already points back to deploy.
-                return self.create().await;
-            } else {
-                anyhow::bail!(
-                    "Cannot deploy app as no app.yaml was found in path '{}'",
-                    app_config_path.display()
-                )
-            }
+        if !app_config_path.is_file()
+            || self.template.is_some()
+            || self.package.is_some()
+            || self.use_local_manifest
+        {
+            // Create already points back to deploy.
+            return self.create().await;
         }
 
         assert!(app_config_path.is_file());
@@ -648,10 +668,7 @@ pub async fn wait_app(
                             if !quiet {
                                 eprintln!();
                             }
-                            eprintln!(
-                                "{} Deployment complete, new version reachable at {check_url}",
-                                "𖥔".yellow().bold()
-                            );
+                            eprintln!("{} Deployment complete", "𖥔".yellow().bold());
                             break;
                         }
 
