@@ -5,6 +5,8 @@ use crate::{
 };
 use colored::Colorize;
 use dialoguer::Confirm;
+use hyper::Body;
+use indicatif::{ProgressBar, ProgressStyle};
 use std::{
     collections::BTreeMap,
     path::{Path, PathBuf},
@@ -41,11 +43,12 @@ pub(super) async fn upload(
     hash: &PackageHash,
     timeout: humantime::Duration,
     package: &Package,
+    pb: ProgressBar,
 ) -> anyhow::Result<String> {
     let hash_str = hash.to_string();
     let hash_str = hash_str.trim_start_matches("sha256:");
 
-    let url = {
+    let session_uri = {
         let default_timeout_secs = Some(60 * 30);
         let q = wasmer_api::query::get_signed_url_for_package_upload(
             client,
@@ -63,7 +66,7 @@ pub(super) async fn upload(
         }
     };
 
-    tracing::info!("signed url is: {url}");
+    tracing::info!("signed url is: {session_uri}");
 
     let client = reqwest::Client::builder()
         .default_headers(reqwest::header::HeaderMap::default())
@@ -72,7 +75,7 @@ pub(super) async fn upload(
         .unwrap();
 
     let res = client
-        .post(&url)
+        .post(&session_uri)
         .header(reqwest::header::CONTENT_LENGTH, "0")
         .header(reqwest::header::CONTENT_TYPE, "application/octet-stream")
         .header("x-goog-resumable", "start");
@@ -114,39 +117,51 @@ pub(super) async fn upload(
     let bytes = package.serialize()?;
 
     let total_bytes = bytes.len();
+    pb.set_length(total_bytes.try_into().unwrap());
+    pb.set_style(ProgressStyle::with_template("{spinner:.yellow} [{elapsed_precise}] [{bar:.white}] {bytes}/{total_bytes} ({bytes_per_sec}, {eta})")
+                 .unwrap()
+                 .progress_chars("█▉▊▋▌▍▎▏  ")
+                 .tick_strings(&["✶", "✸", "✹", "✺", "✹", "✷", "✶"]));
     tracing::info!("webc is {total_bytes} bytes long");
 
-    let chunk_size = 1_048_576; // 1MB - 315s / 100MB
-    let chunks = bytes.chunks(chunk_size);
-    let mut total_bytes_sent = 0;
+    let chunk_size = (total_bytes / 20).min(10485760);
 
-    let client = reqwest::Client::builder().build().unwrap();
+    let stream = futures::stream::unfold(0, move |offset| {
+        let pb = pb.clone();
+        let bytes = bytes.clone();
+        async move {
+            if offset >= total_bytes {
+                return None;
+            }
 
-    for chunk in chunks {
-        let n = chunk.len();
+            let start = offset;
 
-        let start = total_bytes_sent;
-        let end = start + chunk.len().saturating_sub(1);
-        let content_range = format!("bytes {start}-{end}/{total_bytes}");
+            let end = if (start + chunk_size) >= total_bytes {
+                total_bytes
+            } else {
+                start + chunk_size
+            };
 
-        let res = client
-            .put(&session_uri)
-            .header(reqwest::header::CONTENT_TYPE, "application/octet-stream")
-            .header(reqwest::header::CONTENT_LENGTH, format!("{}", chunk.len()))
-            .header("Content-Range".to_string(), content_range)
-            .body(chunk.to_vec());
+            let n = end - start;
+            let next_chunk = bytes.slice(start..end);
+            pb.inc(n as u64);
 
-        res.send()
-            .await
-            .map(|response| response.error_for_status())
-            .map_err(|e| {
-                anyhow::anyhow!("cannot send request to {session_uri} (chunk {start}..{end}): {e}",)
-            })??;
+            Some((Ok::<_, std::io::Error>(next_chunk), offset + n))
+        }
+    });
 
-        total_bytes_sent += n;
-    }
+    let res = client
+        .put(&session_uri)
+        .header(reqwest::header::CONTENT_TYPE, "application/octet-stream")
+        .header(reqwest::header::CONTENT_LENGTH, format!("{}", total_bytes))
+        .body(Body::wrap_stream(stream));
 
-    Ok(url)
+    res.send()
+        .await
+        .map(|response| response.error_for_status())
+        .map_err(|e| anyhow::anyhow!("error uploading package to {session_uri}: {e}",))??;
+
+    Ok(session_uri)
 }
 
 /// Read and return a manifest given a path.
