@@ -344,6 +344,10 @@ impl WritableJournal for FilteredJournalTx {
         };
         self.inner.write(evt)
     }
+
+    fn flush(&self) -> anyhow::Result<()> {
+        self.inner.flush()
+    }
 }
 
 impl ReadableJournal for FilteredJournalRx {
@@ -362,6 +366,10 @@ impl WritableJournal for FilteredJournal {
     fn write<'a>(&'a self, entry: JournalEntry<'a>) -> anyhow::Result<LogWriteResult> {
         self.tx.write(entry)
     }
+
+    fn flush(&self) -> anyhow::Result<()> {
+        self.tx.flush()
+    }
 }
 
 impl ReadableJournal for FilteredJournal {
