@@ -9,10 +9,11 @@ use rusqlite::{params, Connection, OpenFlags, TransactionBehavior};
 use tar::Builder;
 use thiserror::Error;
 use time::{self, OffsetDateTime};
+use wasmer_config::package::{PackageIdent, MANIFEST_FILE_NAME};
 
 use crate::publish::PublishWait;
+use crate::WasmerConfig;
 use crate::{package::builder::validate::ValidationPolicy, publish::SignArchiveResult};
-use crate::{WasmerConfig, PACKAGE_TOML_FALLBACK_NAME};
 
 const MIGRATIONS: &[(i32, &str)] = &[
     (0, include_str!("./sql/migrations/0000.sql")),
@@ -22,7 +23,8 @@ const MIGRATIONS: &[(i32, &str)] = &[
 
 const CURRENT_DATA_VERSION: usize = MIGRATIONS.len();
 
-/// CLI options for the `wasmer publish` command
+/// An abstraction for the action of publishing a named or unnamed package.
+#[derive(Debug)]
 pub struct Publish {
     /// Registry to publish to
     pub registry: Option<String>,
@@ -30,7 +32,9 @@ pub struct Publish {
     pub dry_run: bool,
     /// Run the publish command without any output
     pub quiet: bool,
-    /// Override the package of the uploaded package in the wasmer.toml
+    /// Override the namespace of the package to upload
+    pub package_namespace: Option<String>,
+    /// Override the name of the package to upload
     pub package_name: Option<String>,
     /// Override the package version of the uploaded package in the wasmer.toml
     pub version: Option<semver::Version>,
@@ -63,8 +67,8 @@ enum PackageBuildError {
 }
 
 impl Publish {
-    /// Executes `wasmer publish`
-    pub fn execute(&self) -> Result<(), anyhow::Error> {
+    /// Publish the package to the selected (or default) registry.
+    pub async fn execute(&self) -> Result<Option<PackageIdent>, anyhow::Error> {
         let input_path = match self.package_path.as_ref() {
             Some(s) => std::env::current_dir()?.join(s),
             None => std::env::current_dir()?,
@@ -105,7 +109,7 @@ impl Publish {
         let manifest = std::fs::read_to_string(&manifest_path)
             .map_err(|e| anyhow::anyhow!("could not find manifest: {e}"))
             .with_context(|| anyhow::anyhow!("{}", manifest_path.display()))?;
-        let mut manifest = wasmer_toml::Manifest::parse(&manifest)?;
+        let mut manifest = wasmer_config::package::Manifest::parse(&manifest)?;
 
         let manifest_path_canon = manifest_path.canonicalize()?;
         let manifest_dir = manifest_path_canon
@@ -114,11 +118,15 @@ impl Publish {
             .to_owned();
 
         if let Some(package_name) = self.package_name.as_ref() {
-            manifest.package.name = package_name.to_string();
+            if let Some(ref mut package) = manifest.package {
+                package.name = Some(package_name.clone());
+            }
         }
 
         if let Some(version) = self.version.as_ref() {
-            manifest.package.version = version.clone();
+            if let Some(ref mut package) = manifest.package {
+                package.version = Some(version.clone());
+            }
         }
 
         let archive_dir = tempfile::TempDir::new()?;
@@ -158,11 +166,7 @@ impl Publish {
 
         if self.dry_run {
             // dry run: publish is done here
-
-            println!(
-                "🚀 Successfully published package `{}@{}`",
-                manifest.package.name, manifest.package.version
-            );
+            println!("🚀 Package published successfully!");
 
             let path = archive_dir.into_path();
             eprintln!("Archive persisted at: {}", path.display());
@@ -171,7 +175,7 @@ impl Publish {
                 "Publish succeeded, but package was not published because it was run in dry-run mode"
             );
 
-            return Ok(());
+            return Ok(None);
         }
 
         crate::publish::try_chunked_uploading(
@@ -194,7 +198,9 @@ impl Publish {
             self.quiet,
             self.wait,
             self.timeout,
+            self.package_namespace.clone(),
         )
+        .await
     }
 
     fn validation_policy(&self) -> Box<dyn ValidationPolicy> {
@@ -217,7 +223,7 @@ struct ConstructedPackageArchive {
 
 fn construct_tar_gz(
     archive_dir: &Path,
-    manifest: &wasmer_toml::Manifest,
+    manifest: &wasmer_config::package::Manifest,
     manifest_path: &Path,
 ) -> Result<ConstructedPackageArchive, anyhow::Error> {
     // This is an assert instead of returned error because this is a programmer error.
@@ -228,31 +234,46 @@ fn construct_tar_gz(
         .context("manifest path has no parent directory")?;
 
     let mut builder = Builder::new(Vec::new());
-    builder.append_path_with_name(manifest_path, PACKAGE_TOML_FALLBACK_NAME)?;
+    builder.append_path_with_name(
+        manifest_path,
+        manifest_path
+            .file_name()
+            .map(|s| s.to_str().unwrap_or_default())
+            .unwrap_or(MANIFEST_FILE_NAME),
+    )?;
 
     let manifest_string = toml::to_string(&manifest)?;
 
-    let package = &manifest.package;
     let modules = &manifest.modules;
 
-    let readme = match package.readme.as_ref() {
-        None => None,
-        Some(s) => {
-            let path = append_path_to_tar_gz(&mut builder, manifest_dir, s).map_err(|(p, e)| {
-                PackageBuildError::ErrorBuildingPackage(format!("{}", p.display()), e)
-            })?;
-            Some(std::fs::read_to_string(path)?)
+    let readme = if let Some(ref package) = manifest.package {
+        match package.readme.as_ref() {
+            None => None,
+            Some(s) => {
+                let path =
+                    append_path_to_tar_gz(&mut builder, manifest_dir, s).map_err(|(p, e)| {
+                        PackageBuildError::ErrorBuildingPackage(format!("{}", p.display()), e)
+                    })?;
+                Some(std::fs::read_to_string(path)?)
+            }
         }
+    } else {
+        None
     };
 
-    let license = match package.license_file.as_ref() {
-        None => None,
-        Some(s) => {
-            let path = append_path_to_tar_gz(&mut builder, manifest_dir, s).map_err(|(p, e)| {
-                PackageBuildError::ErrorBuildingPackage(format!("{}", p.display()), e)
-            })?;
-            Some(std::fs::read_to_string(path)?)
+    let license = if let Some(ref package) = manifest.package {
+        match package.license_file.as_ref() {
+            None => None,
+            Some(s) => {
+                let path =
+                    append_path_to_tar_gz(&mut builder, manifest_dir, s).map_err(|(p, e)| {
+                        PackageBuildError::ErrorBuildingPackage(format!("{}", p.display()), e)
+                    })?;
+                Some(std::fs::read_to_string(path)?)
+            }
         }
+    } else {
+        None
     };
 
     for module in modules {
@@ -612,7 +633,7 @@ mod validate {
     };
 
     pub(crate) fn validate_directory(
-        manifest: &wasmer_toml::Manifest,
+        manifest: &wasmer_config::package::Manifest,
         registry: &str,
         pkg_path: PathBuf,
         callbacks: &mut dyn ValidationPolicy,
@@ -630,10 +651,12 @@ mod validate {
         if would_change_package_privacy(manifest, registry, auth_token)?
             && callbacks.on_package_privacy_changed(manifest).is_break()
         {
-            if manifest.package.private {
-                return Err(ValidationError::WouldBecomePrivate.into());
-            } else {
-                return Err(ValidationError::WouldBecomePublic.into());
+            if let Some(package) = &manifest.package {
+                if package.private {
+                    return Err(ValidationError::WouldBecomePrivate.into());
+                } else {
+                    return Err(ValidationError::WouldBecomePublic.into());
+                }
             }
         }
 
@@ -644,29 +667,37 @@ mod validate {
 
     /// Check if publishing this manifest would change the package's privacy.
     fn would_change_package_privacy(
-        manifest: &wasmer_toml::Manifest,
+        manifest: &wasmer_config::package::Manifest,
         registry: &str,
         auth_token: &str,
     ) -> Result<bool, ValidationError> {
-        let result = crate::query_package_from_registry(
-            registry,
-            &manifest.package.name,
-            None,
-            Some(auth_token),
-        );
+        match &manifest.package {
+            Some(pkg) => {
+                if let Some(ref name) = pkg.name {
+                    let result =
+                        crate::query_package_from_registry(registry, name, None, Some(auth_token));
 
-        match result {
-            Ok(package_version) => Ok(package_version.is_private != manifest.package.private),
-            Err(QueryPackageError::NoPackageFound { .. }) => {
-                // The package hasn't been published yet
-                Ok(false)
+                    match result {
+                        Ok(package_version) => Ok(package_version.is_private != pkg.private),
+                        Err(QueryPackageError::NoPackageFound { .. }) => {
+                            // The package hasn't been published yet
+                            Ok(false)
+                        }
+                        Err(e) => Err(e.into()),
+                    }
+                } else {
+                    Ok(false)
+                }
             }
-            Err(e) => Err(e.into()),
+
+            // This manifest refers to an unnamed package:
+            // as of now, unnamed packages are private by default.
+            None => Ok(false),
         }
     }
 
     fn validate_module(
-        module: &wasmer_toml::Module,
+        module: &wasmer_config::package::Module,
         registry: &str,
         pkg_path: &Path,
     ) -> Result<(), ValidationError> {
@@ -751,7 +782,7 @@ mod validate {
     }
 
     fn validate_bindings(
-        bindings: &wasmer_toml::Bindings,
+        bindings: &wasmer_config::package::Bindings,
         base_directory_path: &Path,
     ) -> Result<(), ValidationError> {
         // Note: checking for referenced files will make sure they all exist.
@@ -770,7 +801,7 @@ mod validate {
         #[error("Failed to read file {file}; {error}")]
         MiscCannotRead { file: String, error: String },
         #[error(transparent)]
-        Imports(#[from] wasmer_toml::ImportsError),
+        Imports(#[from] wasmer_config::package::ImportsError),
         #[error("Unable to update the interfaces database")]
         UpdatingInterfaces(#[source] anyhow::Error),
         #[error("Aborting because publishing the package would make it public")]
@@ -812,7 +843,7 @@ mod validate {
         /// How should publishing proceed when a module is invalid?
         fn on_invalid_module(
             &mut self,
-            module: &wasmer_toml::Module,
+            module: &wasmer_config::package::Module,
             error: &ValidationError,
         ) -> ControlFlow<(), ()>;
 
@@ -820,7 +851,7 @@ mod validate {
         /// privacy? (i.e. by making a private package publicly available).
         fn on_package_privacy_changed(
             &mut self,
-            manifest: &wasmer_toml::Manifest,
+            manifest: &wasmer_config::package::Manifest,
         ) -> ControlFlow<(), ()>;
     }
 
@@ -834,7 +865,7 @@ mod validate {
 
         fn on_invalid_module(
             &mut self,
-            _module: &wasmer_toml::Module,
+            _module: &wasmer_config::package::Module,
             _error: &ValidationError,
         ) -> ControlFlow<(), ()> {
             unreachable!()
@@ -842,7 +873,7 @@ mod validate {
 
         fn on_package_privacy_changed(
             &mut self,
-            _manifest: &wasmer_toml::Manifest,
+            _manifest: &wasmer_config::package::Manifest,
         ) -> ControlFlow<(), ()> {
             unreachable!()
         }
@@ -858,7 +889,7 @@ mod validate {
 
         fn on_invalid_module(
             &mut self,
-            module: &wasmer_toml::Module,
+            module: &wasmer_config::package::Module,
             error: &ValidationError,
         ) -> ControlFlow<(), ()> {
             let module_name = &module.name;
@@ -884,30 +915,30 @@ mod validate {
 
         fn on_package_privacy_changed(
             &mut self,
-            manifest: &wasmer_toml::Manifest,
+            manifest: &wasmer_config::package::Manifest,
         ) -> ControlFlow<(), ()> {
-            let privacy = if manifest.package.private {
-                "private"
-            } else {
-                "public"
-            };
-            let prompt =
-                format!("This will make the package {privacy}. Would you like to continue?");
+            if let Some(pkg) = &manifest.package {
+                let privacy = if pkg.private { "private" } else { "public" };
+                let prompt =
+                    format!("This will make the package {privacy}. Would you like to continue?");
 
-            match dialoguer::Confirm::new()
-                .with_prompt(prompt)
-                .default(false)
-                .interact()
-            {
-                Ok(true) => ControlFlow::Continue(()),
-                Ok(false) => ControlFlow::Break(()),
-                Err(e) => {
-                    tracing::error!(
+                match dialoguer::Confirm::new()
+                    .with_prompt(prompt)
+                    .default(false)
+                    .interact()
+                {
+                    Ok(true) => ControlFlow::Continue(()),
+                    Ok(false) => ControlFlow::Break(()),
+                    Err(e) => {
+                        tracing::error!(
                         error = &e as &dyn std::error::Error,
                         "Unable to check whether the user wants to change the package's privacy",
                     );
-                    ControlFlow::Break(())
+                        ControlFlow::Break(())
+                    }
                 }
+            } else {
+                ControlFlow::Continue(())
             }
         }
     }
@@ -922,7 +953,7 @@ mod validate {
 
         fn on_invalid_module(
             &mut self,
-            _module: &wasmer_toml::Module,
+            _module: &wasmer_config::package::Module,
             _error: &ValidationError,
         ) -> ControlFlow<(), ()> {
             ControlFlow::Break(())
@@ -930,7 +961,7 @@ mod validate {
 
         fn on_package_privacy_changed(
             &mut self,
-            _manifest: &wasmer_toml::Manifest,
+            _manifest: &wasmer_config::package::Manifest,
         ) -> ControlFlow<(), ()> {
             ControlFlow::Break(())
         }
@@ -971,7 +1002,7 @@ runner = "https://webc.org/runner/wcgi"
         std::fs::write(&manifest_path, manifest_str).unwrap();
         std::fs::write(mp.join("module.wasm"), "()").unwrap();
 
-        let manifest = wasmer_toml::Manifest::parse(manifest_str).unwrap();
+        let manifest = wasmer_config::package::Manifest::parse(manifest_str).unwrap();
 
         let meta = construct_tar_gz(archive_dir.path(), &manifest, &manifest_path).unwrap();
 
@@ -1030,7 +1061,7 @@ exports = "crum-sort.wai"
         std::fs::write(mp.join("crumsort_wasm.wasm"), "()").unwrap();
         std::fs::write(mp.join("crum-sort.wai"), "/// crum-sort.wai").unwrap();
 
-        let manifest = wasmer_toml::Manifest::parse(manifest_str).unwrap();
+        let manifest = wasmer_config::package::Manifest::parse(manifest_str).unwrap();
         let meta = construct_tar_gz(archive_dir.path(), &manifest, &manifest_path).unwrap();
 
         let mut data = std::io::Cursor::new(std::fs::read(meta.archive_path).unwrap());
