@@ -86,6 +86,16 @@ pub enum MemoryError {
     /// Returned when a shared memory is required, but the given memory is not shared.
     #[error("The memory is not shared")]
     MemoryNotShared,
+    /// Returned when trying to call a memory operation that is not supported by
+    /// the particular memory implementation.
+    #[error("tried to call an unsupported memory operation: {message}")]
+    UnsupportedOperation {
+        /// Message describing the unsupported operation.
+        message: String,
+    },
+    /// The memory does not support atomic operations.
+    #[error("The memory does not support atomic operations")]
+    AtomicsNotSupported,
     /// A user defined error value, used for error cases not listed above.
     #[error("A user-defined error occurred: {0}")]
     Generic(String),
@@ -95,7 +105,7 @@ pub enum MemoryError {
 ///
 /// Note: this error is not standard to WebAssembly, but it's
 /// useful to determine the import issue on the API side.
-#[derive(Error, Debug)]
+#[derive(Error, Debug, Clone)]
 pub enum ImportError {
     /// Incompatible Import Type.
     /// This error occurs when the import types mismatch.
