@@ -1,6 +1,8 @@
 use std::fmt::{Debug, Display};
 
-use crate::runtime::resolver::{PackageSpecifier, PackageSummary};
+use wasmer_config::package::{PackageIdent, PackageSource};
+
+use crate::runtime::resolver::PackageSummary;
 
 /// Something that packages can be downloaded from.
 #[async_trait::async_trait]
@@ -15,18 +17,27 @@ pub trait Source: Sync + Debug {
     /// should return [`QueryError::NotFound`] or [`QueryError::NoMatches`].
     ///
     /// [dep]: crate::runtime::resolver::Dependency
-    async fn query(&self, package: &PackageSpecifier) -> Result<Vec<PackageSummary>, QueryError>;
+    async fn query(&self, package: &PackageSource) -> Result<Vec<PackageSummary>, QueryError>;
 
     /// Run [`Source::query()`] and get the [`PackageSummary`] for the latest
     /// version.
-    async fn latest(&self, pkg: &PackageSpecifier) -> Result<PackageSummary, QueryError> {
+    async fn latest(&self, pkg: &PackageSource) -> Result<PackageSummary, QueryError> {
         let candidates = self.query(pkg).await?;
-        candidates
-            .into_iter()
-            .max_by(|left, right| left.pkg.version.cmp(&right.pkg.version))
-            .ok_or(QueryError::NoMatches {
-                archived_versions: Vec::new(),
-            })
+
+        match pkg {
+            PackageSource::Ident(PackageIdent::Named(_)) => candidates
+                .into_iter()
+                .max_by(|left, right| {
+                    let left_version = left.pkg.id.as_named().map(|x| &x.version);
+                    let right_version = right.pkg.id.as_named().map(|x| &x.version);
+
+                    left_version.cmp(&right_version)
+                })
+                .ok_or(QueryError::NoMatches {
+                    archived_versions: Vec::new(),
+                }),
+            _ => candidates.into_iter().next().ok_or(QueryError::NotFound),
+        }
     }
 }
 
@@ -36,7 +47,7 @@ where
     D: std::ops::Deref<Target = S> + Debug + Send + Sync,
     S: Source + ?Sized + Send + Sync + 'static,
 {
-    async fn query(&self, package: &PackageSpecifier) -> Result<Vec<PackageSummary>, QueryError> {
+    async fn query(&self, package: &PackageSource) -> Result<Vec<PackageSummary>, QueryError> {
         (**self).query(package).await
     }
 }
