@@ -4,7 +4,7 @@ impl<'a, 'c> JournalSyscallPlayer<'a, 'c> {
     #[allow(clippy::result_large_err)]
     pub(crate) unsafe fn action_init_module(
         &mut self,
-        wasm_hash: [u8; 8],
+        wasm_hash: Box<[u8]>,
         differ_ethereal: Option<&mut Vec<JournalEntry<'a>>>,
     ) -> Result<(), WasiRuntimeError> {
         tracing::trace!("Replay journal - InitModule {:?}", wasm_hash);
