@@ -13,6 +13,27 @@ pub fn fd_fdstat_set_flags(
     mut ctx: FunctionEnvMut<'_, WasiEnv>,
     fd: WasiFd,
     flags: Fdflags,
+) -> Result<Errno, WasiError> {
+    let ret = fd_fdstat_set_flags_internal(&mut ctx, fd, flags)?;
+    let env = ctx.data();
+
+    if ret == Errno::Success {
+        #[cfg(feature = "journal")]
+        if env.enable_journal {
+            JournalEffector::save_fd_set_flags(&mut ctx, fd, flags).map_err(|err| {
+                tracing::error!("failed to save file set flags event - {}", err);
+                WasiError::Exit(ExitCode::Errno(Errno::Fault))
+            })?;
+        }
+    }
+
+    Ok(ret)
+}
+
+pub(crate) fn fd_fdstat_set_flags_internal(
+    ctx: &mut FunctionEnvMut<'_, WasiEnv>,
+    fd: WasiFd,
+    flags: Fdflags,
 ) -> Result<Errno, WasiError> {
     {
         let env = ctx.data();
