@@ -31,7 +31,7 @@ pub fn sock_accept<M: MemorySize>(
 
     let nonblocking = fd_flags.contains(Fdflags::NONBLOCK);
 
-    let (fd, addr) = wasi_try_ok!(sock_accept_internal(env, sock, fd_flags, nonblocking)?);
+    let (fd, _, _) = wasi_try_ok!(sock_accept_internal(env, sock, fd_flags, nonblocking)?);
 
     wasi_try_mem_ok!(ro_fd.write(&memory, fd));
 
@@ -66,15 +66,24 @@ pub fn sock_accept_v2<M: MemorySize>(
 
     let nonblocking = fd_flags.contains(Fdflags::NONBLOCK);
 
-    let (fd, addr) = wasi_try_ok!(sock_accept_internal(env, sock, fd_flags, nonblocking)?);
+    let (fd, local_addr, peer_addr) =
+        wasi_try_ok!(sock_accept_internal(env, sock, fd_flags, nonblocking)?);
 
     #[cfg(feature = "journal")]
     if ctx.data().enable_journal {
-        JournalEffector::save_sock_accepted(&mut ctx, sock, fd, addr, fd_flags, nonblocking)
-            .map_err(|err| {
-                tracing::error!("failed to save sock_accepted event - {}", err);
-                WasiError::Exit(ExitCode::Errno(Errno::Fault))
-            })?;
+        JournalEffector::save_sock_accepted(
+            &mut ctx,
+            sock,
+            fd,
+            local_addr,
+            peer_addr,
+            fd_flags,
+            nonblocking,
+        )
+        .map_err(|err| {
+            tracing::error!("failed to save sock_accepted event - {}", err);
+            WasiError::Exit(ExitCode::Errno(Errno::Fault))
+        })?;
     }
 
     let env = ctx.data();
@@ -83,8 +92,8 @@ pub fn sock_accept_v2<M: MemorySize>(
     wasi_try_ok!(crate::net::write_ip_port(
         &memory,
         ro_addr,
-        addr.ip(),
-        addr.port()
+        peer_addr.ip(),
+        peer_addr.port()
     ));
 
     Ok(Errno::Success)
@@ -95,12 +104,12 @@ pub(crate) fn sock_accept_internal(
     sock: WasiFd,
     mut fd_flags: Fdflags,
     mut nonblocking: bool,
-) -> Result<Result<(WasiFd, SocketAddr), Errno>, WasiError> {
+) -> Result<Result<(WasiFd, SocketAddr, SocketAddr), Errno>, WasiError> {
     let state = env.state();
     let inodes = &state.inodes;
 
     let tasks = env.tasks().clone();
-    let (child, addr, fd_flags) = wasi_try_ok_ok!(__sock_asyncify(
+    let (child, local_addr, peer_addr, fd_flags) = wasi_try_ok_ok!(__sock_asyncify(
         env,
         sock,
         Rights::SOCK_ACCEPT,
@@ -114,10 +123,11 @@ pub(crate) fn sock_accept_internal(
                 .ok()
                 .flatten()
                 .unwrap_or(Duration::from_secs(30));
+            let local_addr = socket.addr_local()?;
             socket
                 .accept(tasks.deref(), nonblocking, Some(timeout))
                 .await
-                .map(|a| (a.0, a.1, fd_flags))
+                .map(|a| (a.0, local_addr, a.1, fd_flags))
         },
     ));
 
@@ -146,5 +156,5 @@ pub(crate) fn sock_accept_internal(
     let fd = wasi_try_ok_ok!(state.fs.create_fd(rights, rights, new_flags, 0, inode));
     Span::current().record("fd", fd);
 
-    Ok(Ok((fd, addr)))
+    Ok(Ok((fd, local_addr, peer_addr)))
 }
